TIVITA names every artefact of a recording YYYY_MM_DD_HH_MM_SS_<what>.
This extracts the acquisition time from such a name.
TIVITA names every artefact of a recording YYYY_MM_DD_HH_MM_SS_<what>.
This extracts the acquisition time from such a name.